@@ -16,20 +16,26 @@
  */
 package org.sejda.core.support.util;
 
-import static java.lang.Character.*;
+import static java.lang.Character.DIRECTIONALITY_LEFT_TO_RIGHT;
+import static java.lang.Character.DIRECTIONALITY_LEFT_TO_RIGHT_EMBEDDING;
+import static java.lang.Character.DIRECTIONALITY_LEFT_TO_RIGHT_OVERRIDE;
+import static java.lang.Character.DIRECTIONALITY_RIGHT_TO_LEFT;
+import static java.lang.Character.DIRECTIONALITY_RIGHT_TO_LEFT_ARABIC;
+import static java.lang.Character.DIRECTIONALITY_RIGHT_TO_LEFT_EMBEDDING;
+import static java.lang.Character.DIRECTIONALITY_RIGHT_TO_LEFT_OVERRIDE;
 
 public final class StringUtils {
     private StringUtils() {
         // hide
     }
 
-
     // Useful to debug weird strings
     public static String asUnicodes(String in) {
-        if(in == null) return null;
+        if (in == null)
+            return null;
 
         StringBuilder result = new StringBuilder();
-        for (int offset = 0; offset < in.length(); ) {
+        for (int offset = 0; offset < in.length();) {
             int codepoint = in.codePointAt(offset);
             result.append("\\U+").append(Integer.toHexString(codepoint).toUpperCase());
             offset += Character.charCount(codepoint);
@@ -37,17 +43,15 @@ public final class StringUtils {
         return result.toString();
     }
 
-
     public static String normalizeLineEndings(String in) {
         return in.replaceAll("\\r\\n", "\n");
     }
 
     public static String isolateRTLIfRequired(String s) {
-        if(isRtl(s)) {
+        if (isRtl(s)) {
             return '\u2068' + s + '\u2069';
-        } else {
-            return s;
         }
+        return s;
     }
 
     public static boolean isRtl(String string) {
@@ -59,16 +63,16 @@ public final class StringUtils {
             byte d = Character.getDirectionality(string.charAt(i));
 
             switch (d) {
-                case DIRECTIONALITY_RIGHT_TO_LEFT:
-                case DIRECTIONALITY_RIGHT_TO_LEFT_ARABIC:
-                case DIRECTIONALITY_RIGHT_TO_LEFT_EMBEDDING:
-                case DIRECTIONALITY_RIGHT_TO_LEFT_OVERRIDE:
-                    return true;
+            case DIRECTIONALITY_RIGHT_TO_LEFT:
+            case DIRECTIONALITY_RIGHT_TO_LEFT_ARABIC:
+            case DIRECTIONALITY_RIGHT_TO_LEFT_EMBEDDING:
+            case DIRECTIONALITY_RIGHT_TO_LEFT_OVERRIDE:
+                return true;
 
-                case DIRECTIONALITY_LEFT_TO_RIGHT:
-                case DIRECTIONALITY_LEFT_TO_RIGHT_EMBEDDING:
-                case DIRECTIONALITY_LEFT_TO_RIGHT_OVERRIDE:
-                    return false;
+            case DIRECTIONALITY_LEFT_TO_RIGHT:
+            case DIRECTIONALITY_LEFT_TO_RIGHT_EMBEDDING:
+            case DIRECTIONALITY_LEFT_TO_RIGHT_OVERRIDE:
+                return false;
             }
         }
 
