@@ -22,7 +22,8 @@ package org.sejda.core.service;
 
 import static org.hamcrest.CoreMatchers.is;
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertThat;
+import static org.hamcrest.MatcherAssert.assertThat;
+import static org.sejda.TestUtils.encryptedAtRest;
 
 import java.io.IOException;
 
@@ -201,6 +202,29 @@ public abstract class RotateTaskTest extends BaseTaskTest<RotateParameters> {
         });
     }
 
+    @Test
+    public void encryptionAtRestTest() throws IOException {
+        parameters = new RotateParameters(Rotation.DEGREES_180, PredefinedSetOfPages.ALL_PAGES);
+        parameters.addSource(encryptedAtRest(shortInput()));
+        parameters.setExistingOutputPolicy(ExistingOutputPolicy.OVERWRITE);
+
+        testContext.directoryOutputTo(parameters);
+        execute(parameters);
+        testContext.assertTaskCompleted();
+        testContext.assertPages(4).forEachPdfOutput(d -> d.getPages().forEach(p -> assertEquals(180, p.getRotation())));
+    }
+
+    @Test
+    public void specificResultFilenames() throws IOException {
+        setUpRotateMultipleInputNotRangesContained();
+        testContext.directoryOutputTo(parameters);
+        parameters.addSpecificResultFilename("one.pdf");
+        parameters.addSpecificResultFilename("two.PDF");
+        execute(parameters);
+        testContext.assertTaskCompleted();
+        testContext.assertOutputSize(2).assertOutputContainsFilenames("one.pdf", "two.PDF");
+    }
+
     private void assertPageRotation(PDDocument doc, int pageIndex, int expectedDegrees) {
         assertEquals(expectedDegrees, doc.getPage(pageIndex).getRotation());
     }
