@@ -22,6 +22,7 @@ package org.sejda.model.output;
 
 import java.io.File;
 
+import org.sejda.model.encryption.EncryptionAtRestPolicy;
 import org.sejda.model.exception.TaskOutputVisitException;
 
 /**
@@ -47,4 +48,8 @@ public interface TaskOutput {
      */
     void accept(TaskOutputDispatcher dispatcher) throws TaskOutputVisitException;
 
+    EncryptionAtRestPolicy getEncryptionAtRestPolicy();
+
+    void setEncryptionAtRestPolicy(EncryptionAtRestPolicy encryptionAtRestSecurity);
+
 }
