@@ -22,20 +22,13 @@ package org.sejda.model.parameter;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Mockito.mock;
 
-import java.io.IOException;
-import java.io.InputStream;
 import java.util.Set;
 
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
 import org.sejda.TestUtils;
-import org.sejda.model.input.PdfSource;
-import org.sejda.model.input.PdfStreamSource;
-import org.sejda.model.output.FileTaskOutput;
-import org.sejda.model.output.SingleTaskOutput;
 import org.sejda.model.pdf.PdfMetadataFields;
 
 /**
@@ -72,15 +65,4 @@ public class SetMetadataParametersTest {
         assertTrue(keys.contains(PdfMetadataFields.CREATOR));
         assertFalse(keys.contains(PdfMetadataFields.KEYWORDS));
     }
-
-    @Test
-    public void testInvalidParameters() throws IOException {
-        SetMetadataParameters victim = new SetMetadataParameters();
-        SingleTaskOutput output = new FileTaskOutput(folder.newFile());
-        victim.setOutput(output);
-        InputStream stream = mock(InputStream.class);
-        PdfSource<InputStream> input = PdfStreamSource.newInstanceNoPassword(stream, "name");
-        victim.setSource(input);
-        TestUtils.assertInvalidParameters(victim);
-    }
 }
