@@ -18,17 +18,6 @@
  */
 package org.sejda.impl.sambox;
 
-import static java.util.Optional.ofNullable;
-import static org.sejda.commons.util.IOUtils.closeQuietly;
-import static org.sejda.core.notification.dsl.ApplicationEventsNotifier.notifyEvent;
-import static org.sejda.impl.sambox.component.SignatureClipper.clipSignatures;
-
-import java.io.Closeable;
-import java.io.File;
-import java.util.LinkedList;
-import java.util.Queue;
-import java.util.Set;
-
 import org.apache.commons.io.FilenameUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.sejda.commons.LookupTable;
@@ -62,6 +51,19 @@ import org.sejda.sambox.pdmodel.interactive.annotation.PDAnnotation;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.io.Closeable;
+import java.io.File;
+import java.util.ArrayList;
+import java.util.LinkedList;
+import java.util.List;
+import java.util.Queue;
+import java.util.Set;
+
+import static java.util.Optional.ofNullable;
+import static org.sejda.commons.util.IOUtils.closeQuietly;
+import static org.sejda.core.notification.dsl.ApplicationEventsNotifier.notifyEvent;
+import static org.sejda.impl.sambox.component.SignatureClipper.clipSignatures;
+
 /**
  * SAMBox implementation of the Merge task that merges together a number of documents or part of them.
  * 
@@ -116,9 +118,12 @@ public class MergeTask extends BaseTask<MergeParameters> {
 
         ImagesToPdfDocumentConverter.convertImageMergeInputToPdf(parameters, executionContext());
 
+        List<FooterWriterEntry> footerWriterEntries = new ArrayList<>();
+
         for (PdfMergeInput input : parameters.getPdfInputList()) {
             inputsCounter++;
             LOG.debug("Opening {}", input.getSource());
+            executionContext().notifiableTaskMetadata().setCurrentSource(input.getSource());
             PDDocumentHandler sourceDocumentHandler = input.getSource().open(sourceOpener);
             toClose.add(sourceDocumentHandler);
 
@@ -167,12 +172,17 @@ public class MergeTask extends BaseTask<MergeParameters> {
                         }
                     }
 
-                    long currentPageNumber = pagesCounter + tocCreator.tocNumberOfPages();
+                    boolean isPlacedAfterToc = true;
                     if (parameters.isFirstInputCoverTitle() && inputsCounter == 1) {
                         // the toc will be added after the cover/title pages
-                        currentPageNumber = pagesCounter;
+                        isPlacedAfterToc = false;
                     }
-                    this.footerWriter.addFooter(importedPage, sourceBaseName, currentPageNumber);
+
+                    // we can determine the correct final page numbers only after the ToC has been generated
+                    // otherwise we don't know how many pages the ToC consists of
+                    // queue up footer writer items for after ToC generation
+                    footerWriterEntries.add(new FooterWriterEntry(importedPage, sourceBaseName, pagesCounter, isPlacedAfterToc));
+                    
                     LOG.trace("Added imported page");
                 } catch (PageNotFoundException e) {
                     executionContext().assertTaskIsLenient(e);
@@ -180,8 +190,7 @@ public class MergeTask extends BaseTask<MergeParameters> {
                             .taskWarning(String.format("Page %d was skipped, could not be processed", currentPage), e);
                 }
             }
-            relativePagesCounter = 0;
-
+            
             outlineMerger.updateOutline(sourceDocumentHandler.getUnderlyingPDDocument(), input.getSource().getName(),
                     pagesLookup);
 
@@ -202,6 +211,8 @@ public class MergeTask extends BaseTask<MergeParameters> {
             notifyEvent(executionContext().notifiableTaskMetadata()).stepsCompleted(++currentStep).outOf(totalSteps);
         }
 
+        executionContext().notifiableTaskMetadata().clearCurrentSource();
+
         if (outlineMerger.hasOutline()) {
             LOG.debug("Adding generated outline");
             destinationDocument.setDocumentOutline(outlineMerger.getOutline());
@@ -218,17 +229,24 @@ public class MergeTask extends BaseTask<MergeParameters> {
             new PdfScaler(ScaleType.PAGE).scalePages(destinationDocument.getUnderlyingPDDocument());
         }
 
+        int tocNumberOfPages = 0;
         if (tocCreator.hasToc()) {
             LOG.debug("Adding generated ToC");
             try {
                 // add ToC as first page or after the cover/title pages
                 int beforePageNumber = parameters.isFirstInputCoverTitle() ? firstInputNumberOfPages : 0;
-                tocCreator.addToC(beforePageNumber);
+                tocNumberOfPages = tocCreator.addToC(beforePageNumber);
             } catch (TaskException e) {
                 notifyEvent(executionContext().notifiableTaskMetadata())
                         .taskWarning("Unable to create the Table of Contents", e);
             }
         }
+        
+        LOG.debug("Writing page footers");
+        for(FooterWriterEntry entry: footerWriterEntries) {
+            long finalPageNumber = entry.isPlacedAfterToc ? entry.pageNumber + tocNumberOfPages : entry.pageNumber;
+            this.footerWriter.addFooter(entry.page, entry.fileName, finalPageNumber);
+        }
 
         if (catalogPageLabelsMerger.hasPageLabels()) {
             LOG.debug("Adding merged /Catalog /PageLabels");
@@ -257,5 +275,18 @@ public class MergeTask extends BaseTask<MergeParameters> {
         closeResources();
         outputWriter = null;
     }
+    
+    private static class FooterWriterEntry {
+        final PDPage page; 
+        final String fileName; 
+        final long pageNumber;
+        final boolean isPlacedAfterToc;
 
+        public FooterWriterEntry(PDPage page, String fileName, long pageNumber, boolean isPlacedAfterToc) {
+            this.page = page;
+            this.fileName = fileName;
+            this.pageNumber = pageNumber;
+            this.isPlacedAfterToc = isPlacedAfterToc;
+        }
+    }
 }
