@@ -73,15 +73,7 @@ import static org.sejda.sambox.cos.COSName.V;
 import static org.sejda.sambox.pdmodel.interactive.form.PDFieldFactory.createField;
 
 import java.io.IOException;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collection;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Objects;
-import java.util.Optional;
-import java.util.Set;
-import java.util.UUID;
+import java.util.*;
 import java.util.function.BiConsumer;
 import java.util.function.BiFunction;
 import java.util.function.Consumer;
@@ -130,13 +122,33 @@ public class AcroFormsMerger {
             PDTerminalField existing, LookupTable<PDField> fieldsLookup) -> {
         PDField previouslyCreated = ofNullable(getMergedField(existing.getFullyQualifiedName()))
                 .orElseGet(() -> fieldsLookup.lookup(existing));
-        if (isNull(previouslyCreated)) {
+        
+        boolean shouldCreateNew = isNull(previouslyCreated);
+        boolean shouldCreateNewAndRename = previouslyCreated != null &&
+                (        
+                    // different types (eg: checkbox vs text)
+                    !previouslyCreated.getClass().equals(existing.getClass()) ||
+                    // different values (eg: john vs jack)
+                    !previouslyCreated.getValueAsString().equals(existing.getValueAsString())
+                ); 
+
+        if (shouldCreateNew || shouldCreateNewAndRename) {
             previouslyCreated = PDFieldFactory.createFieldAddingChildToParent(this.form,
                     existing.getCOSObject().duplicate(),
                     (PDNonTerminalField) fieldsLookup.lookup(existing.getParent()));
+            
+            if(shouldCreateNewAndRename) {
+                LOG.warn("Cannot merge terminal field because another field with the same name but different value already exists: {}",
+                        existing.getFullyQualifiedName());
+
+                previouslyCreated.setPartialName(String.format("%s%s%d", removeDotsIfAny(existing.getPartialName()),
+                        random, ++counter));
+            }
+
             previouslyCreated.getCOSObject().removeItem(COSName.KIDS);
             fieldsLookup.addLookupEntry(existing, previouslyCreated);
         }
+        
         if (!previouslyCreated.isTerminal()) {
             LOG.warn("Cannot merge terminal field because a non terminal field with the same name already exists: {}",
                     existing.getFullyQualifiedName());
@@ -150,15 +162,23 @@ public class AcroFormsMerger {
         PDTerminalField newField = (PDTerminalField) PDFieldFactory.createFieldAddingChildToParent(this.form,
                 existing.getCOSObject().duplicate(), (PDNonTerminalField) fieldsLookup.lookup(existing.getParent()));
         if (nonNull(getMergedField(existing.getFullyQualifiedName())) || fieldsLookup.hasLookupFor(existing)) {
-            newField.setPartialName(String.format("%s%s%d", existing.getPartialName(), random, ++counter));
-            LOG.info("Existing terminal field renamed from {} to {}", existing.getPartialName(),
-                    newField.getPartialName());
+            String partialName = removeDotsIfAny(existing.getPartialName());
+            newField.setPartialName(String.format("%s%s%d", partialName, random, ++counter));
+            LOG.info("Existing terminal field renamed from {} to {}", partialName, newField.getPartialName());
         }
         newField.getCOSObject().removeItem(COSName.KIDS);
         fieldsLookup.addLookupEntry(existing, newField);
         return newField;
     };
 
+    // dots are not allowed in the partial name, but still broken documents may exist
+    private static String removeDotsIfAny(String s) {
+        if(s == null) {
+            return null;
+        }
+        return s.replace(".", "");
+    }
+
     private final BiConsumer<PDField, LookupTable<PDField>> createOrReuseNonTerminalField = (PDField existing,
             LookupTable<PDField> fieldsLookup) -> {
                 // do we aready have a lookup for this?
@@ -175,7 +195,8 @@ public class AcroFormsMerger {
                         existing.getCOSObject().duplicate(),
                         (PDNonTerminalField) fieldsLookup.lookup(existing.getParent()));
                 mergedField.getCOSObject().removeItem(COSName.KIDS);
-                mergedField.setPartialName(String.format("%s%s%d", existing.getPartialName(), random, ++counter));
+                mergedField.setPartialName(String.format("%s%s%d", removeDotsIfAny(existing.getPartialName()), 
+                        random, ++counter));
                 LOG.warn("Cannot reuse merged terminal field {} as a non terminal field, renaming it to {}",
                         existing.getPartialName(), mergedField.getPartialName());
             }
@@ -192,7 +213,7 @@ public class AcroFormsMerger {
         PDField newField = PDFieldFactory.createFieldAddingChildToParent(this.form, field.getCOSObject().duplicate(),
                 (PDNonTerminalField) fieldsLookup.lookup(field.getParent()));
         if (getMergedField(field.getFullyQualifiedName()) != null || fieldsLookup.hasLookupFor(field)) {
-            newField.setPartialName(String.format("%s%s%d", field.getPartialName(), random, ++counter));
+            newField.setPartialName(String.format("%s%s%d", removeDotsIfAny(field.getPartialName()), random, ++counter));
             LOG.info("Existing non terminal field renamed from {} to {}", field.getPartialName(),
                     newField.getPartialName());
         }
