@@ -91,6 +91,11 @@ public class PDDocumentHandler implements Closeable {
         if (document == null) {
             throw new IllegalArgumentException("PDDocument cannot be null.");
         }
+
+        if(Boolean.getBoolean(Sejda.PERFORM_EAGER_ASSERTIONS_PROPERTY_NAME)) {
+            document.assertNumberOfPagesIsAccurate();
+        }
+        
         this.document = document;
         permissions = new PDDocumentAccessPermission(document);
     }
