@@ -18,21 +18,6 @@
  */
 package org.sejda.impl.sambox.component;
 
-import static java.util.Optional.of;
-import static java.util.Optional.ofNullable;
-import static org.sejda.commons.util.RequireUtils.requireIOCondition;
-import static org.sejda.commons.util.RequireUtils.requireNotNullArg;
-
-import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileNotFoundException;
-import java.io.IOException;
-import java.io.InputStream;
-import java.io.OutputStream;
-import java.util.GregorianCalendar;
-import java.util.zip.DeflaterInputStream;
-
-import org.sejda.commons.util.IOUtils;
 import org.sejda.io.SeekableSource;
 import org.sejda.model.exception.SejdaRuntimeException;
 import org.sejda.model.exception.TaskIOException;
@@ -47,36 +32,50 @@ import org.sejda.sambox.cos.COSStream;
 import org.sejda.sambox.cos.IndirectCOSObjectIdentifier;
 import org.sejda.sambox.pdmodel.graphics.color.PDColorSpace;
 
+import java.io.ByteArrayInputStream;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.FileNotFoundException;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
+import java.util.GregorianCalendar;
+import java.util.zip.DeflaterInputStream;
+
+import static java.util.Optional.of;
+import static java.util.Optional.ofNullable;
+import static org.sejda.commons.util.RequireUtils.requireIOCondition;
+import static org.sejda.commons.util.RequireUtils.requireNotNullArg;
+
 /**
  * A read only, filtered, encryptable, indirect reference length {@link COSStream} whose purpose is to be read by the PDF writer during the write process. This can allow to create
  * streams from File input streams and predefine the expected dictionary without having to read anything into memory.
- * 
- * @author Andrea Vacondio
  *
+ * @author Andrea Vacondio
  */
 public class ReadOnlyFilteredCOSStream extends COSStream {
-    private InputStreamSupplier<InputStream> stream;
-    private long length;
-    private COSDictionary wrapped;
+    private InputStreamSupplier<InputStream> supplier;
+    private final long length;
+    private final COSDictionary wrapped;
 
-    ReadOnlyFilteredCOSStream(COSDictionary existingDictionary, InputStream stream, long length) {
-        this(existingDictionary, () -> stream, length);
-        requireNotNullArg(stream, "input stream cannot be null");
+    ReadOnlyFilteredCOSStream(COSDictionary existingDictionary, InputStream supplier, long length) {
+        this(existingDictionary, () -> supplier, length);
+        requireNotNullArg(supplier, "input stream cannot be null");
     }
 
-    public ReadOnlyFilteredCOSStream(COSDictionary existingDictionary, InputStreamSupplier<InputStream> stream,
+    public ReadOnlyFilteredCOSStream(COSDictionary existingDictionary, InputStreamSupplier<InputStream> supplier,
             long length) {
-        super(ofNullable(existingDictionary)
-                .orElseThrow(() -> new IllegalArgumentException("wrapped dictionary cannot be null")));
-        requireNotNullArg(stream, "input stream provider cannot be null");
-        this.stream = stream;
+        super(ofNullable(existingDictionary).orElseThrow(
+                () -> new IllegalArgumentException("wrapped dictionary cannot be null")));
+        requireNotNullArg(supplier, "input stream provider cannot be null");
+        this.supplier = supplier;
         this.length = length;
         this.wrapped = existingDictionary;
     }
 
     @Override
     protected InputStream doGetFilteredStream() throws IOException {
-        return stream.get();
+        return supplier.get();
     }
 
     @Override
@@ -162,7 +161,8 @@ public class ReadOnlyFilteredCOSStream extends COSStream {
 
     @Override
     public void close() throws IOException {
-        IOUtils.closeQuietly(stream.get());
+        //consistent with COSStream that once closed has COSStream::getFilteredStream returning an empty ByteArrayInputStream
+        this.supplier = () -> new ByteArrayInputStream(new byte[0]);
     }
 
     /**
@@ -176,8 +176,7 @@ public class ReadOnlyFilteredCOSStream extends COSStream {
         requireNotNullArg(existing, "input stream cannot be null");
         // let's make sure we get the unencrypted and filtered
         existing.setEncryptor(null);
-        return new ReadOnlyFilteredCOSStream(existing, () -> existing.getFilteredStream(),
-                existing.getFilteredLength());
+        return new ReadOnlyFilteredCOSStream(existing, existing::getFilteredStream, existing.getFilteredLength());
     }
 
     /**
