@@ -37,7 +37,8 @@ public class TextWithFont {
         return text;
     }
 
+    @Override
     public String toString() {
-        return "[" + this.font.getName() + "] '" + getText() + "'";
+        return "[" + (this.font == null ? "null" : this.font.getName()) + "] '" + getText() + "'";
     }
 }
