@@ -29,7 +29,8 @@ import java.io.IOException;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
-import org.sejda.common.LookupTable;
+import org.sejda.commons.LookupTable;
+import org.sejda.commons.util.IOUtils;
 import org.sejda.io.SeekableSources;
 import org.sejda.model.pdf.form.AcroFormPolicy;
 import org.sejda.sambox.cos.COSName;
@@ -39,9 +40,9 @@ import org.sejda.sambox.pdmodel.PDPage;
 import org.sejda.sambox.pdmodel.interactive.annotation.PDAnnotation;
 import org.sejda.sambox.pdmodel.interactive.form.PDAcroForm;
 import org.sejda.sambox.pdmodel.interactive.form.PDField;
+import org.sejda.sambox.pdmodel.interactive.form.PDNonTerminalField;
 import org.sejda.sambox.pdmodel.interactive.form.PDRadioButton;
 import org.sejda.sambox.pdmodel.interactive.form.PDTerminalField;
-import org.sejda.util.IOUtils;
 
 /**
  * @author Andrea Vacondio
@@ -139,6 +140,37 @@ public class AcroFormsMergerTest {
         }
     }
 
+    @Test
+    public void mergeWithHierarchySameRootNodeName() throws IOException {
+        PDDocument destination = new PDDocument();
+        AcroFormsMerger victim = new AcroFormsMerger(AcroFormPolicy.MERGE, destination);
+        mapping.clear();
+        annotationsLookup.clear();
+
+        try (PDDocument anotherDoc = PDFParser.parse(SeekableSources.inMemorySeekableSourceFrom(
+                getClass().getClassLoader().getResourceAsStream("pdf/forms/simple_form_with_hierarchy.pdf")))) {
+            mapping.addLookupEntry(anotherDoc.getPage(0), new PDPage());
+            annotationsLookup = new AnnotationsDistiller(anotherDoc).retainRelevantAnnotations(mapping);
+            victim.mergeForm(anotherDoc.getDocumentCatalog().getAcroForm(), annotationsLookup);
+        }
+        mapping.clear();
+        annotationsLookup.clear();
+
+        try (PDDocument anotherDoc = PDFParser.parse(SeekableSources.inMemorySeekableSourceFrom(getClass()
+                .getClassLoader().getResourceAsStream("pdf/forms/simple_form_with_hierarchy_same_root.pdf")))) {
+            mapping.addLookupEntry(anotherDoc.getPage(0), new PDPage());
+            annotationsLookup = new AnnotationsDistiller(anotherDoc).retainRelevantAnnotations(mapping);
+            victim.mergeForm(anotherDoc.getDocumentCatalog().getAcroForm(), annotationsLookup);
+        }
+
+        PDAcroForm form = victim.getForm();
+        assertFalse(form.getFields().isEmpty());
+        assertNotNull(form.getField("node.leaf"));
+        assertNotNull(form.getField("node.text"));
+        assertNotNull(form.getField("node.anothertext"));
+        assertEquals(1, form.getFields().size());
+    }
+
     @Test
     public void mergeRenamingWithHierarchy() throws IOException {
         PDDocument destination = new PDDocument();
@@ -187,23 +219,88 @@ public class AcroFormsMergerTest {
     }
 
     @Test
-    public void mergeOrphans() throws IOException {
+    // AcroForm fields array is empty. Widget and Field dictionaries are merged and there is no fields hierarchy
+    public void mergeOrphansFieldsMergedWidgetNoHierarchy() throws IOException {
+        PDDocument destination = new PDDocument();
+        AcroFormsMerger victim = new AcroFormsMerger(AcroFormPolicy.MERGE, destination);
+        mapping.clear();
+        annotationsLookup.clear();
+
+        try (PDDocument anotherDoc = PDFParser.parse(SeekableSources.inMemorySeekableSourceFrom(getClass()
+                .getClassLoader().getResourceAsStream("pdf/forms/form_orphan_fields_merged_dic_no_hierarchy.pdf")))) {
+            PDPage destPage = new PDPage();
+            mapping.addLookupEntry(anotherDoc.getPage(0), destPage);
+            annotationsLookup = new AnnotationsDistiller(anotherDoc).retainRelevantAnnotations(mapping);
+            victim.mergeForm(anotherDoc.getDocumentCatalog().getAcroForm(), annotationsLookup);
+
+            assertEquals(2, victim.getForm().getFields().size());
+            assertEquals(4, destPage.getAnnotations().size());
+        }
+    }
+
+    @Test
+    // AcroForm fields array is empty. Widget is a kid of the Field dictionaries and there is no fields hierarchy
+    public void mergeOrphansFieldsWithWidgetKidsNoHierarchy() throws IOException {
         PDDocument destination = new PDDocument();
         AcroFormsMerger victim = new AcroFormsMerger(AcroFormPolicy.MERGE, destination);
         mapping.clear();
         annotationsLookup.clear();
 
         try (PDDocument anotherDoc = PDFParser.parse(SeekableSources.inMemorySeekableSourceFrom(
-                getClass().getClassLoader().getResourceAsStream("pdf/forms/form_orphan_fields.pdf")))) {
+                getClass().getClassLoader().getResourceAsStream("pdf/forms/form_orphan_fields_no_hierarchy.pdf")))) {
             PDPage destPage = new PDPage();
             mapping.addLookupEntry(anotherDoc.getPage(0), destPage);
             annotationsLookup = new AnnotationsDistiller(anotherDoc).retainRelevantAnnotations(mapping);
             victim.mergeForm(anotherDoc.getDocumentCatalog().getAcroForm(), annotationsLookup);
 
-            assertFalse(victim.getForm().getFields().isEmpty());
-            PDAcroForm form = victim.getForm();
-            assertEquals(2, form.getFields().size());
-            assertEquals(6, destPage.getAnnotations().size());
+            assertEquals(2, victim.getForm().getFields().size());
+            assertEquals(4, destPage.getAnnotations().size());
+        }
+    }
+
+    @Test
+    // AcroForm fields array is empty. Widget is a kid of the Field dictionaries and there is a fields hierarchy
+    public void mergeOrphansFieldsWithWidgetKidsWithHierarchy() throws IOException {
+        PDDocument destination = new PDDocument();
+        AcroFormsMerger victim = new AcroFormsMerger(AcroFormPolicy.MERGE, destination);
+        mapping.clear();
+        annotationsLookup.clear();
+
+        try (PDDocument anotherDoc = PDFParser.parse(SeekableSources.inMemorySeekableSourceFrom(
+                getClass().getClassLoader().getResourceAsStream("pdf/forms/form_orphan_fields_with_hierarchy.pdf")))) {
+            PDPage destPage = new PDPage();
+            mapping.addLookupEntry(anotherDoc.getPage(0), destPage);
+            annotationsLookup = new AnnotationsDistiller(anotherDoc).retainRelevantAnnotations(mapping);
+            victim.mergeForm(anotherDoc.getDocumentCatalog().getAcroForm(), annotationsLookup);
+
+            assertEquals(1, victim.getForm().getFields().size());
+            PDField field = victim.getForm().getFields().get(0);
+            assertFalse(field.isTerminal());
+            assertEquals(2, ((PDNonTerminalField) field).getChildren().size());
+            assertEquals(4, destPage.getAnnotations().size());
+        }
+    }
+
+    @Test
+    // AcroForm fields array is empty. Widget and Field dictionaries are merged and there is a fields hierarchy
+    public void mergeOrphansFieldsMergedWidgetWithHierarchy() throws IOException {
+        PDDocument destination = new PDDocument();
+        AcroFormsMerger victim = new AcroFormsMerger(AcroFormPolicy.MERGE, destination);
+        mapping.clear();
+        annotationsLookup.clear();
+
+        try (PDDocument anotherDoc = PDFParser.parse(SeekableSources.inMemorySeekableSourceFrom(getClass()
+                .getClassLoader().getResourceAsStream("pdf/forms/form_orphan_fields_merged_dic_with_hierarchy.pdf")))) {
+            PDPage destPage = new PDPage();
+            mapping.addLookupEntry(anotherDoc.getPage(0), destPage);
+            annotationsLookup = new AnnotationsDistiller(anotherDoc).retainRelevantAnnotations(mapping);
+            victim.mergeForm(anotherDoc.getDocumentCatalog().getAcroForm(), annotationsLookup);
+
+            assertEquals(1, victim.getForm().getFields().size());
+            PDField field = victim.getForm().getFields().get(0);
+            assertFalse(field.isTerminal());
+            assertEquals(2, ((PDNonTerminalField) field).getChildren().size());
+            assertEquals(4, destPage.getAnnotations().size());
         }
     }
 
