@@ -18,34 +18,39 @@
  */
 package org.sejda.impl.sambox.component;
 
+import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.instanceOf;
 import static org.hamcrest.Matchers.is;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertThat;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.any;
+import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
 import java.io.IOException;
 import java.util.List;
+import java.util.Map;
 import java.util.Set;
 
 import org.junit.Test;
 import org.sejda.io.SeekableSources;
+import org.sejda.sambox.cos.COSArray;
+import org.sejda.sambox.cos.COSInteger;
 import org.sejda.sambox.cos.COSName;
 import org.sejda.sambox.input.PDFParser;
 import org.sejda.sambox.pdmodel.PDDocument;
 import org.sejda.sambox.pdmodel.PDDocumentCatalog;
 import org.sejda.sambox.pdmodel.PDPage;
+import org.sejda.sambox.pdmodel.common.PDRectangle;
 import org.sejda.sambox.pdmodel.interactive.action.PDActionGoTo;
 import org.sejda.sambox.pdmodel.interactive.documentnavigation.destination.PDNamedDestination;
 import org.sejda.sambox.pdmodel.interactive.documentnavigation.destination.PDPageDestination;
 import org.sejda.sambox.pdmodel.interactive.documentnavigation.destination.PDPageFitDestination;
 import org.sejda.sambox.pdmodel.interactive.documentnavigation.destination.PDPageFitHeightDestination;
+import org.sejda.sambox.pdmodel.interactive.documentnavigation.destination.PDPageXYZDestination;
 import org.sejda.sambox.pdmodel.interactive.documentnavigation.outline.PDDocumentOutline;
 import org.sejda.sambox.pdmodel.interactive.documentnavigation.outline.PDOutlineItem;
 
@@ -116,6 +121,34 @@ public class OutlineUtilsTest {
         assertEquals(dest, OutlineUtils.toPageDestination(victim, catalog).get());
     }
 
+    @Test(expected = IllegalArgumentException.class)
+    public void pageDestinationForNull() {
+        OutlineUtils.pageDestinationFor(null);
+    }
+
+    @Test
+    public void pageDestinationFor() {
+        PDPage page = new PDPage(PDRectangle.A4);
+        PDPageXYZDestination noRotation = OutlineUtils.pageDestinationFor(page);
+        assertEquals(0, noRotation.getLeft());
+        assertEquals((int) PDRectangle.A4.getHeight(), noRotation.getTop());
+
+        page.setRotation(90);
+        PDPageXYZDestination rotation90 = OutlineUtils.pageDestinationFor(page);
+        assertEquals(0, rotation90.getLeft());
+        assertEquals(0, rotation90.getTop());
+
+        page.setRotation(180);
+        PDPageXYZDestination rotation180 = OutlineUtils.pageDestinationFor(page);
+        assertEquals((int) PDRectangle.A4.getWidth(), rotation180.getLeft());
+        assertEquals(0, rotation180.getTop());
+
+        page.setRotation(270);
+        PDPageXYZDestination rotation270 = OutlineUtils.pageDestinationFor(page);
+        assertEquals((int) PDRectangle.A4.getWidth(), rotation270.getLeft());
+        assertEquals((int) PDRectangle.A4.getHeight(), rotation270.getTop());
+    }
+
     @Test(expected = IllegalArgumentException.class)
     public void clonePageDestinationNullDest() {
         OutlineUtils.clonePageDestination(null, new PDPage());
@@ -249,4 +282,78 @@ public class OutlineUtilsTest {
         assertEquals(2, flat.size());
         assertEquals("child2", flat.get(0).title);
     }
+
+    @Test
+    public void resolvePageDestination() throws IOException {
+        PDPage page1 = new PDPage();
+        PDPage page2 = new PDPage();
+        PDDocument document = new PDDocument();
+        document.addPage(page1);
+        document.addPage(page2);
+        PDDocumentOutline outlines = new PDDocumentOutline();
+        PDOutlineItem root = new PDOutlineItem();
+        root.setTitle("title");
+        PDOutlineItem child = new PDOutlineItem();
+        child.setTitle("child");
+        child.setDestination(page2);
+        PDOutlineItem child2 = new PDOutlineItem();
+        child2.setTitle("child2");
+        child2.setDestination(page1);
+        child2.getCOSObject().getDictionaryObject(COSName.DEST, COSArray.class).set(0, COSInteger.ONE);
+        root.addFirst(child);
+        root.addLast(child2);
+        outlines.addFirst(root);
+        document.getDocumentCatalog().setDocumentOutline(outlines);
+        assertNotNull(OutlineUtils.resolvePageDestination((PDPageDestination) child2.getDestination(), document));
+        assertNotNull(OutlineUtils.resolvePageDestination((PDPageDestination) child.getDestination(), document));
+        PDPageDestination negative = new PDPageXYZDestination();
+        negative.setPageNumber(-1);
+        assertNull(OutlineUtils.resolvePageDestination(negative, document));
+        PDPageDestination notFound = new PDPageXYZDestination();
+        notFound.setPageNumber(10);
+        assertNull(OutlineUtils.resolvePageDestination(notFound, document));
+    }
+
+    @Test
+    public void pageGroupedPageDestinations() {
+        PDPage page1 = new PDPage();
+        PDPage page2 = new PDPage();
+        PDPage page3 = new PDPage();
+        PDDocument document = new PDDocument();
+        document.addPage(page1);
+        document.addPage(page2);
+        document.addPage(page3);
+        PDDocumentOutline outlines = new PDDocumentOutline();
+        PDOutlineItem root = new PDOutlineItem();
+        root.setTitle("title");
+        PDOutlineItem child = new PDOutlineItem();
+        child.setTitle("child");
+        child.setDestination(page2);
+        PDOutlineItem child2 = new PDOutlineItem();
+        child2.setTitle("child2");
+        child2.setDestination(page1);
+        PDOutlineItem child3 = new PDOutlineItem();
+        child3.setTitle("child3");
+        PDPageFitHeightDestination gotoDest = new PDPageFitHeightDestination();
+        gotoDest.setLeft(50);
+        gotoDest.setPage(page1);
+        PDActionGoTo action = new PDActionGoTo();
+        action.setDestination(gotoDest);
+        child3.setAction(action);
+        child2.getCOSObject().getDictionaryObject(COSName.DEST, COSArray.class).set(0, COSInteger.ONE);
+        PDOutlineItem child4 = new PDOutlineItem();
+        child4.setTitle("child4");
+        child4.setDestination(page3);
+        child3.addLast(child4);
+        root.addFirst(child);
+        root.addLast(child2);
+        root.addLast(child3);
+        outlines.addFirst(root);
+        document.getDocumentCatalog().setDocumentOutline(outlines);
+        Map<PDPage, Set<PDPageDestination>> victim = OutlineUtils.pageGroupedOutlinePageDestinations(document);
+        assertEquals(3, victim.size());
+        assertEquals(1, victim.get(page1).size());
+        assertEquals(2, victim.get(page2).size());
+        assertEquals(1, victim.get(page3).size());
+    }
 }
