@@ -18,19 +18,22 @@
  */
 package org.sejda.impl.sambox.component;
 
+import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.is;
 import static org.junit.Assert.*;
 import static org.sejda.TestUtils.encryptedAtRest;
 import static org.sejda.core.service.BaseTaskTest.customNonPdfInput;
 import static org.sejda.core.service.BaseTaskTest.customNonPdfInputAsFileSource;
 
-import java.io.*;
+import java.io.IOException;
 
 import org.apache.commons.io.IOUtils;
 import org.junit.Test;
 import org.sejda.model.exception.TaskIOException;
 import org.sejda.sambox.pdmodel.graphics.color.PDDeviceRGB;
 import org.sejda.sambox.pdmodel.graphics.image.PDImageXObject;
+import org.sejda.sambox.pdmodel.graphics.image.UnsupportedImageFormatException;
+import org.sejda.sambox.util.filetypedetector.FileType;
 
 public class PageImageWriterTest {
 
@@ -42,8 +45,22 @@ public class PageImageWriterTest {
         assertThat(result.getHeight(), is(3840));
         assertThat(result.getWidth(), is(5760));
 
-        assertTrue("Original bytes should be used",
-                IOUtils.contentEquals(result.getCOSObject().getFilteredStream(), customNonPdfInput("image/large.jpg").getSource()));
+        assertTrue("Original bytes should be used", IOUtils.contentEquals(result.getCOSObject().getFilteredStream(),
+                customNonPdfInput("image/large.jpg").getSource()));
+    }
+
+    @Test
+    public void testHeif_unsupported() throws TaskIOException {
+        Exception ex = assertThrows(TaskIOException.class, () -> {
+            PageImageWriter.toPDXImageObject(customNonPdfInput("image/sample_heic.jpg"));   
+        });
+        
+        Throwable cause = ex.getCause();
+        assertEquals(cause.getClass(), UnsupportedImageFormatException.class);
+        UnsupportedImageFormatException uife = (UnsupportedImageFormatException) cause;
+        
+        assertEquals(uife.getFileType(), FileType.HEIF);
+        assertEquals(uife.getFilename(), "sample_heic.jpg");
     }
 
     @Test
@@ -69,7 +86,8 @@ public class PageImageWriterTest {
         assertThat(result.getWidth(), is(1400));
 
         assertFalse("Original bytes should not be used; the image should be converted from CMYK to RGB",
-                IOUtils.contentEquals(result.getCOSObject().getFilteredStream(), customNonPdfInput("image/cmyk.jpg").getSource()));
+                IOUtils.contentEquals(result.getCOSObject().getFilteredStream(),
+                        customNonPdfInput("image/cmyk.jpg").getSource()));
     }
 
     @Test
@@ -80,7 +98,8 @@ public class PageImageWriterTest {
         assertThat(result.getWidth(), is(1400));
 
         assertFalse("Original bytes should not be used; the image should be converted from CMYK to RGB",
-                IOUtils.contentEquals(result.getCOSObject().getFilteredStream(), customNonPdfInput("image/cmyk.jpg").getSource()));
+                IOUtils.contentEquals(result.getCOSObject().getFilteredStream(),
+                        customNonPdfInput("image/cmyk.jpg").getSource()));
     }
 
     @Test
@@ -89,7 +108,8 @@ public class PageImageWriterTest {
         assertThat(result.getColorSpace(), is(PDDeviceRGB.INSTANCE));
 
         assertFalse("Original bytes should not be used; the image should be converted from ICC Gray to RGB",
-                IOUtils.contentEquals(result.getCOSObject().getFilteredStream(), customNonPdfInput("image/icc_profile_gray.png").getSource()));
+                IOUtils.contentEquals(result.getCOSObject().getFilteredStream(),
+                        customNonPdfInput("image/icc_profile_gray.png").getSource()));
     }
 
     @Test
@@ -99,19 +119,24 @@ public class PageImageWriterTest {
         assertThat(result.getColorSpace(), is(PDDeviceRGB.INSTANCE));
         assertThat(result.getHeight(), is(3840));
 
-        assertTrue("Decrypted bytes should be used",
-                IOUtils.contentEquals(
-                        result.getCOSObject().getFilteredStream(),
-                        customNonPdfInput("image/large.jpg").getSource()
-                )
-        );
+        assertTrue("Decrypted bytes should be used", IOUtils.contentEquals(result.getCOSObject().getFilteredStream(),
+                customNonPdfInput("image/large.jpg").getSource()));
     }
 
     @Test
     public void encryptedAtRestTest_file() throws TaskIOException, IOException {
 
-        PDImageXObject result = PageImageWriter.toPDXImageObject(encryptedAtRest(customNonPdfInputAsFileSource("image/draft.png")));
+        PDImageXObject result = PageImageWriter
+                .toPDXImageObject(encryptedAtRest(customNonPdfInputAsFileSource("image/draft.png")));
         assertThat(result.getColorSpace(), is(PDDeviceRGB.INSTANCE));
         assertThat(result.getHeight(), is(103));
     }
-}
\ No newline at end of file
+
+    @Test
+    public void testExifRotated() throws TaskIOException {
+
+        PDImageXObject result = PageImageWriter.toPDXImageObject(customNonPdfInput("image/with_exif_orientation.JPG"));
+        assertThat(result.getHeight(), is(3264));
+        assertThat(result.getWidth(), is(2448));
+    }
+}
