@@ -1,10 +1,9 @@
 package org.sejda.impl.sambox.component.image;
 
-import static org.junit.Assert.assertEquals;
-
 import org.junit.Test;
 import org.sejda.core.service.BaseTaskTest;
 import org.sejda.impl.sambox.component.PDDocumentHandler;
+import org.sejda.impl.sambox.util.PixelCompareUtils;
 import org.sejda.model.exception.TaskException;
 import org.sejda.model.input.FileSource;
 
@@ -15,6 +14,6 @@ public class ImagesToPdfDocumentConverterTest {
         FileSource source = BaseTaskTest.customNonPdfInputAsFileSource("image/with_exif_orientation.JPG");
         ImagesToPdfDocumentConverter converter = new ImagesToPdfDocumentConverter();
         PDDocumentHandler d = converter.addPage(source);
-        assertEquals(90, d.getPage(1).getRotation());
+        PixelCompareUtils.assertSimilar(d, "pdf/with_exif_orientation.pdf");
     }
 }
