@@ -346,4 +346,16 @@ public class FontUtilsTest {
         List<String> result = FontUtils.resolveTextFragments("FRIDA", font);
         assertThat(result, is(Arrays.asList("F", "RIDA")));
     }
+
+    @Test
+    public void vectorFontWithSpace() throws TaskIOException, IOException {
+        PDDocument doc = getTestDoc("pdf/font-with-vector-font.pdf");
+        PDFont font = doc.getPage(0).getResources().getFont(COSName.getPDFName("F1"));
+
+        assertThat(FontUtils.canDisplaySpace(font), is(true));
+        
+        List<TextWithFont> result = FontUtils.resolveFonts("31 days", font, doc);
+        assertThat(result.get(0).getText(), is("31 days"));
+        assertThat(result.get(0).getFont(), is(font));
+    }
 }
